@@ -3,49 +3,6 @@ local pn = ToEnumShortString(player)
 local mods = SL[pn].ActiveModifiers
 local sprite
 
--- helper function for returning the player AF
--- works as expected in ScreenGameplay
---     arguments:  pn is short string PlayerNumber like "P1" or "P2"
---     returns:    the "PlayerP1" or "PlayerP2" ActorFrame in ScreenGameplay
---                 or, the unnamed equivalent in ScrenEdit
-local GetPlayerAF = function(pn)
-	local topscreen = SCREENMAN:GetTopScreen()
-	if not topscreen then
-		lua.ReportScriptError("GetPlayerAF() failed to find the player ActorFrame because there is no Screen yet.")
-		return nil
-	end
-
-	local playerAF = nil
-
-	-- Get the player ActorFrame on ScreenGameplay
-	-- It's a direct child of the screen and named "PlayerP1" for P1
-	-- and "PlayerP2" for P2.
-	-- This naming convention is hardcoded in the SM5 engine.
-	--
-	-- ScreenEdit does not name its player ActorFrame, but we can still find it.
-
-	-- find the player ActorFrame in edit mode
-	if (THEME:GetMetric(topscreen:GetName(), "Class") == "ScreenEdit") then
-		-- loop through all nameless children of topscreen
-		-- and find the one that contains the NoteField
-		-- which is thankfully still named "NoteField"
-		for _,nameless_child in ipairs(topscreen:GetChild("")) do
-			if nameless_child:GetChild("NoteField") then
-				playerAF = nameless_child
-				break
-			end
-		end
-
-	-- find the player ActorFrame in gameplay
-	else
-		local player_af = topscreen:GetChild("Player"..pn)
-		if player_af then
-			playerAF = player_af
-		end
-	end
-
-	return playerAF
-end
 ------------------------------------------------------------
 -- A profile might ask for a judgment graphic that doesn't exist
 -- If so, use the first available Judgment graphic
@@ -63,9 +20,14 @@ if file_to_load == "None" then
 			if ToEnumShortString(param.TapNoteScore) == "W1" and mods.ShowFaPlusWindow then
 				if not IsW0Judgment(param, player) and not IsAutoplay(player) then
 					frame = 1
-					
-					for col,tapnote in pairs(param.Notes) do
-						local tnt = ToEnumShortString(tapnote:GetTapNoteType())
+					if param.Notes ~= nil then
+						for col,tapnote in pairs(param.Notes) do
+							local tnt = ToEnumShortString(tapnote:GetTapNoteType())
+							if tnt == "Tap" or tnt == "HoldHead" or tnt == "Lift" then
+								GetPlayerAF(pn):GetChild("NoteField"):did_tap_note(col, "TapNoteScore_W1", --[[bright]] true)
+							end
+						end
+					elseif param.TapNote ~= nil then
 						if tnt == "Tap" or tnt == "HoldHead" or tnt == "Lift" then
 							GetPlayerAF(pn):GetChild("NoteField"):did_tap_note(col, "TapNoteScore_W1", --[[bright]] true)
 						end
